# -*- encoding: utf-8 -*-
require 'spec_helper'

describe Mongoid::Collation do
  describe '.collation' do
    before do
      class Container
        include Mongoid::Document
        include Mongoid::Collation

        field :string, type: String
        collation :string, locale: :pl
      end
    end

    after do
      Object.send(:remove_const, :Container)
    end

    context 'given multiple strings' do
      let(:strings) { ['Ą', 'A', 'Ś', 'Ł', 'Ó', 'W'] }
      let(:strings_ordered) { ['A', 'Ą', 'Ł', 'Ó', 'Ś', 'W'] }

      before do
        strings.shuffle.each do |string|
          Container.create!(string: string)
        end
      end

      context 'given sorting by hash' do
        let(:sorted_by_string) { Container.all.sort(string: 1).to_a }

        it 'sorts according to collation' do
          expect(sorted_by_string.map(&:string)).
            to eq(strings_ordered)
        end
      end

      context 'given sorting by Origin::Key' do
        let(:sorted_by_string) { Container.all.sort(:string.asc).to_a }

        it 'sorts according to collation' do
          expect(sorted_by_string.map(&:string)).
            to eq(strings_ordered)
        end
      end
    end
  end
end
